@@ -5,25 +5,33 @@ use core::future::Future;
 use core::pin::Pin;
 use core::task::{Context, Poll, Waker};
 use core::time::Duration;
-use fixed_queue::spsc::{Receiver, Sender, Spsc};
 use futures_core::stream::Stream;
 use futures_intrusive::timer::{Clock, MockClock};
 use futures_intrusive::timer::{GenericTimerService, Timer, TimerFuture};
+use heapless::mpmc::MpMcQueue;
 use spin::{Lazy, Mutex};
 
-const SPSC_LEN: usize = 30;
-static SPSC: Spsc<Runnable, SPSC_LEN> = Spsc::new();
-static SENDER: Lazy<Sender<'static, Runnable, SPSC_LEN>> =
-    Lazy::new(|| SPSC.take_sender().unwrap());
-static RECVER: Lazy<Receiver<'static, Runnable, SPSC_LEN>> =
-    Lazy::new(|| SPSC.take_recver().unwrap());
-static WAKER: Mutex<Option<Waker>> = Mutex::new(None);
+const SPSC_LEN: usize = 32;
 static CLOCK: MockClock = MockClock::new();
 static TIMER: Lazy<GenericTimerService<Mutex<()>>> = Lazy::new(|| GenericTimerService::new(&CLOCK));
+static EXEC: Executor = Executor::new();
+
+pub struct Executor {
+    queue: MpMcQueue<Runnable, SPSC_LEN>,
+    waker: Mutex<Option<Waker>>,
+}
+impl Executor {
+    const fn new() -> Self {
+        Self {
+            queue: MpMcQueue::new(),
+            waker: Mutex::new(None),
+        }
+    }
+}
 
 fn schedule(runnable: Runnable) {
-    SENDER.send(runnable).unwrap();
-    if let Some(waker) = WAKER.lock().take() {
+    EXEC.queue.enqueue(runnable).unwrap();
+    if let Some(waker) = EXEC.waker.lock().take() {
         waker.wake();
     }
 }
@@ -56,21 +64,17 @@ impl TaskStream {
         TaskStream { _inner: () }
     }
     pub fn get_task(&self) -> Option<Runnable> {
-        if let Ok(task) = RECVER.try_recv() {
-            Some(task)
-        } else {
-            None
-        }
+        EXEC.queue.dequeue()
     }
 }
 impl Stream for TaskStream {
     type Item = Runnable;
     fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<Self::Item>> {
-        if let Ok(task) = RECVER.try_recv() {
+        if let Some(task) = self.get_task() {
             cx.waker().wake_by_ref();
             Poll::Ready(Some(task))
         } else {
-            *WAKER.lock() = Some(cx.waker().clone());
+            *EXEC.waker.lock() = Some(cx.waker().clone());
             Poll::Pending
         }
     }
